pub enum FunSource {
Normal,
AdtConstructor,
TraitDefault {
trait_ref: TraitDeclRef,
item_id: TraitMethodId,
},
TraitImpl {
impl_ref: TraitImplRef,
trait_ref: TraitDeclRef,
item_id: TraitMethodId,
reuses_default: bool,
},
VTableShim,
GlobalInitializer(GlobalDeclRef),
TargetDependent {
dispatcher: FunDeclRef,
},
}Expand description
Where a given function came from.
Variants
Normal
A normal function.
AdtConstructor
A synthetic function representing an ADT constructor.
TraitDefault
A default method in a trait declaration.
Fields
trait_ref: TraitDeclRefThe trait declaration this item belongs to.
item_id: TraitMethodIdThe method this corresponds to.
TraitImpl
A method in a trait implementation.
Fields
impl_ref: TraitImplRefThe trait implementation the method belongs to.
trait_ref: TraitDeclRefThe trait declaration that the impl block implements.
item_id: TraitMethodIdThe method this corresponds to.
VTableShim
Wraps a concrete implementation of a method into a function that takes dyn Trait as its
Self type. This shim casts the receiver to the known concrete type and calls the real
method.
GlobalInitializer(GlobalDeclRef)
The initializer for a global.
TargetDependent
A target-specific variant behind a TargetDispatch façade. The dispatcher is the function
with the Body::TargetDispatch body that dispatches to this function.
Fields
dispatcher: FunDeclRefTrait Implementations
Sourceimpl AstVisitable for FunSource
impl AstVisitable for FunSource
Sourcefn drive<V: VisitAst>(&self, v: &mut V) -> ControlFlow<V::Break>
fn drive<V: VisitAst>(&self, v: &mut V) -> ControlFlow<V::Break>
visit_$any
method if it exists, otherwise visit_inner.Sourcefn drive_mut<V: VisitAstMut>(&mut self, v: &mut V) -> ControlFlow<V::Break>
fn drive_mut<V: VisitAstMut>(&mut self, v: &mut V) -> ControlFlow<V::Break>
visit_$any
method if it exists, otherwise visit_inner.Sourcefn drive_two<V: ZipAst>(&self, other: &Self, v: &mut V) -> ControlFlow<V::Break>
fn drive_two<V: ZipAst>(&self, other: &Self, v: &mut V) -> ControlFlow<V::Break>
visit_$any
method if it exists, otherwise visit_inner.Sourcefn dyn_visit<T: AstVisitable>(&self, f: impl FnMut(&T))where
Self: Sized,
fn dyn_visit<T: AstVisitable>(&self, f: impl FnMut(&T))where
Self: Sized,
self, in pre-order traversal.Sourcefn dyn_visit_mut<T: AstVisitable>(&mut self, f: impl FnMut(&mut T))where
Self: Sized,
fn dyn_visit_mut<T: AstVisitable>(&mut self, f: impl FnMut(&mut T))where
Self: Sized,
self, in pre-order traversal.Sourceimpl<'de, __State: ?Sized> DeserializeState<'de, __State> for FunSourcewhere
TraitDeclRef: DeserializeState<'de, __State>,
TraitMethodId: DeserializeState<'de, __State>,
TraitImplRef: DeserializeState<'de, __State>,
bool: DeserializeState<'de, __State>,
GlobalDeclRef: DeserializeState<'de, __State>,
FunDeclRef: DeserializeState<'de, __State>,
impl<'de, __State: ?Sized> DeserializeState<'de, __State> for FunSourcewhere
TraitDeclRef: DeserializeState<'de, __State>,
TraitMethodId: DeserializeState<'de, __State>,
TraitImplRef: DeserializeState<'de, __State>,
bool: DeserializeState<'de, __State>,
GlobalDeclRef: DeserializeState<'de, __State>,
FunDeclRef: DeserializeState<'de, __State>,
fn deserialize_state<__D>(
__state: &__State,
__deserializer: __D,
) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl<'s, V> Drive<'s, V> for FunSourcewhere
V: Visitor + Visit<'s, TraitDeclRef> + Visit<'s, TraitMethodId> + Visit<'s, TraitImplRef> + Visit<'s, bool> + Visit<'s, GlobalDeclRef> + Visit<'s, FunDeclRef>,
impl<'s, V> Drive<'s, V> for FunSourcewhere
V: Visitor + Visit<'s, TraitDeclRef> + Visit<'s, TraitMethodId> + Visit<'s, TraitImplRef> + Visit<'s, bool> + Visit<'s, GlobalDeclRef> + Visit<'s, FunDeclRef>,
Sourcefn drive_inner(&'s self, visitor: &mut V) -> ControlFlow<V::Break>
fn drive_inner(&'s self, visitor: &mut V) -> ControlFlow<V::Break>
v.visit() on the immediate contents of self.Sourceimpl<'s, V> DriveMut<'s, V> for FunSourcewhere
V: Visitor + VisitMut<'s, TraitDeclRef> + VisitMut<'s, TraitMethodId> + VisitMut<'s, TraitImplRef> + VisitMut<'s, bool> + VisitMut<'s, GlobalDeclRef> + VisitMut<'s, FunDeclRef>,
impl<'s, V> DriveMut<'s, V> for FunSourcewhere
V: Visitor + VisitMut<'s, TraitDeclRef> + VisitMut<'s, TraitMethodId> + VisitMut<'s, TraitImplRef> + VisitMut<'s, bool> + VisitMut<'s, GlobalDeclRef> + VisitMut<'s, FunDeclRef>,
Sourcefn drive_inner_mut(&'s mut self, visitor: &mut V) -> ControlFlow<V::Break>
fn drive_inner_mut(&'s mut self, visitor: &mut V) -> ControlFlow<V::Break>
v.visit() on the immediate contents of self.Sourceimpl<'s, V> DriveTwo<'s, V> for FunSourcewhere
V: Visitor<Break: Default> + VisitTwo<'s, TraitDeclRef> + VisitTwo<'s, TraitMethodId> + VisitTwo<'s, TraitImplRef> + VisitTwo<'s, bool> + VisitTwo<'s, GlobalDeclRef> + VisitTwo<'s, FunDeclRef>,
impl<'s, V> DriveTwo<'s, V> for FunSourcewhere
V: Visitor<Break: Default> + VisitTwo<'s, TraitDeclRef> + VisitTwo<'s, TraitMethodId> + VisitTwo<'s, TraitImplRef> + VisitTwo<'s, bool> + VisitTwo<'s, GlobalDeclRef> + VisitTwo<'s, FunDeclRef>,
Sourcefn drive_two_inner(
&'s self,
other: &'s Self,
visitor: &mut V,
) -> ControlFlow<V::Break>
fn drive_two_inner( &'s self, other: &'s Self, visitor: &mut V, ) -> ControlFlow<V::Break>
v.visit() on the immediate contents of self and other, if they correspond. If
the values don’t match up, this returns Break(Default::default()).Sourceimpl<__State: ?Sized> SerializeState<__State> for FunSourcewhere
TraitDeclRef: SerializeState<__State>,
TraitMethodId: SerializeState<__State>,
TraitImplRef: SerializeState<__State>,
bool: SerializeState<__State>,
GlobalDeclRef: SerializeState<__State>,
FunDeclRef: SerializeState<__State>,
impl<__State: ?Sized> SerializeState<__State> for FunSourcewhere
TraitDeclRef: SerializeState<__State>,
TraitMethodId: SerializeState<__State>,
TraitImplRef: SerializeState<__State>,
bool: SerializeState<__State>,
GlobalDeclRef: SerializeState<__State>,
FunDeclRef: SerializeState<__State>,
fn serialize_state<__S>(
&self,
__state: &__State,
__serializer: __S,
) -> Result<__S::Ok, __S::Error>where
__S: Serializer,