FunSource

Enum FunSource 

pub enum FunSource {
    Normal,
    TraitDefault {
        trait_ref: TraitDeclRef,
        item_id: TraitMethodId,
    },
    TraitImpl {
        impl_ref: TraitImplRef,
        trait_ref: TraitDeclRef,
        item_id: TraitMethodId,
        reuses_default: bool,
    },
    VTableShim,
    GlobalInitializer(GlobalDeclRef),
    TargetDependent {
        dispatcher: FunDeclRef,
    },
}
Where a given function came from.

Variants



Normal

A normal function.



TraitDefault

A default method in a trait declaration.

Fields

trait_ref: TraitDeclRef

The trait declaration this item belongs to.

item_id: TraitMethodId

The method this corresponds to.



TraitImpl

A method in a trait implementation.

Fields

impl_ref: TraitImplRef

The trait implementation the method belongs to.

trait_ref: TraitDeclRef

The trait declaration that the impl block implements.

item_id: TraitMethodId

The method this corresponds to.

reuses_default: bool

True if the trait decl had a default implementation for this method and this item is a copy of the default item.



VTableShim

Wraps a concrete implementation of a method into a function that takes dyn Trait as its Self type. This shim casts the receiver to the known concrete type and calls the real method.



GlobalInitializer(GlobalDeclRef)

The initializer for a global.



TargetDependent

A target-specific variant behind a TargetDispatch façade. The dispatcher is the function with the Body::TargetDispatch body that dispatches to this function.

Fields

dispatcher: FunDeclRef